..
    This file is part of Invenio.
    Copyright (C) 2017-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

.. _communication-channels:

Communication channels
======================

Chatrooms
---------
Most day-to-day communication is happening in our chatrooms:

- `Public chatroom <https://gitter.im/inveniosoftware/invenio>`_ (for everyone)
- `Developer chatroom <https://gitter.im/inveniosoftware/invenio>`_ (for
  `members <https://github.com/orgs/inveniosoftware/people>`_ of inveniosoftware
  GitHub organisation).

If you want to join the developer chatroom, just ask for an invite on the
public chatroom.

GitHub
------
Most of the developer communication is happening on GitHub. You are stroungly
encouraged to join
`<https://github.com/orgs/inveniosoftware/teams/developers>`_ team and watch
notifications from various `<https://github.com/inveniosoftware/>`_
organisation repositories of interest.

Meetings
--------

Invenio Developer Forum
~~~~~~~~~~~~~~~~~~~~~~~
Monday afternoons at 16:00 CET/CEST time we meet physically at CERN and
virtually over videoconference to discuss interesting development topics.

You can join our Monday forums from anywhere via videoconference. Here the
steps:

- View the `agenda <https://indico.cern.ch/category/6046/>`_
  (`ical feed <https://indico.cern.ch/export/categ/6046.ics?from=-31d>`_).
- Install the videoconferencing client `Vidyo <https://vidyoportal.cern.ch/>`_.
- Join our `virtual room <https://vidyoportal.cern.ch/join/a6GP8E71EU>`_.

Invenio User Group Workshop
~~~~~~~~~~~~~~~~~~~~~~~~~~~
We meet among Invenio users and developers from around the world at a yearly
Invenio User Group Workshop. The workshop consists of a series of
presentations, tutorials, practical exercises, and discussions on topics
related to Invenio digital library management and development. We exchange
knowledge and experiences and drive forward the forthcoming developments of
the Invenio platform.

See list of `upcoming and past <https://indico.cern.ch/category/6240/>`_
workshops.

Other meetings
~~~~~~~~~~~~~~
In addition to above meetings where everyone can join, the following meetings
exists:

- Quarterly project coordination meeting with the Invenio project
  coordinators and architects that help steer the project prioritizes and
  goals.
- Weekly architecture meeting.

Project website
---------------
Our project website, http://inveniosoftware.org, is used to show case Invenio.

Email
-----
You can get in touch with the Invenio management team on
`info@inveniosoftware.org <mailto:info@inveniosoftware.org>`_.

In particular use above email address to report security related issues
privately to us, so we can distribute a security patch before potential
attackers look at the issue.

Twitter
-------
The official Twitter account for Invenio software is used mostly for announcing
new releases and talks at conferences:

- `<https://twitter.com/inveniosoftware>`_

Mailing lists
-------------
The mailing lists are currently not very active and are primiarly listed here
for historical reasons.

- ``project-invenio-announce@cern.ch``: Read-only moderated mailing
  list to announce new Invenio releases and other major news concerning the
  project. `subscribe to announce <https://simba3.web.cern.ch/simba3/SelfSubscription.aspx?groupName=project-invenio-announce>`_,
  `archive <https://groups.cern.ch/group/project-invenio-announce/Lists/Archive/100.aspx>`_
- ``project-invenio-general@cern.ch``: Originally used for discussion among
  users and administrators of Invenio instances. The mailing list has mostly
  been replaced by our public chatroom.
  `subscribe to general <https://simba3.web.cern.ch/simba3/SelfSubscription.aspx?groupName=project-invenio-general>`_,
  `new general archive <https://groups.cern.ch/group/project-invenio-general/Lists/Archive/100.aspx>`_,
  `old general archive <https://groups.cern.ch/group/project-cdsware-users/Lists/Archive/100.aspx>`_
- ``project-invenio-devel@cern.ch``: Originally used for discussion among
  Invenio developers. The mailing list has mostly been replaced by our
  developer chatroom.
  `subscribe to devel <https://simba3.web.cern.ch/simba3/SelfSubscription.aspx?groupName=project-invenio-devel>`_,
  `new devel archive <https://groups.cern.ch/group/project-invenio-devel/Lists/Archive/100.aspx>`_,
  `old devel archive <https://groups.cern.ch/group/project-cdsware-developers/Lists/Archive/100.aspx>`_

Note that all the mailing lists are also archived (as of the 20th of
July, 2011) on `The Mail Archive <http://www.mail-archive.com/>`_.
